@@ -670,6 +670,8 @@ class MainHandler(WheelRESTHandler):
             accum_success = []
             accum_failure = []
 
+            # import pdb; pdb.set_trace()
+            
             for p in clipboard:
                 n = Node.objects.get(tree_path=p)
                 if n:
@@ -734,11 +736,6 @@ class MainHandler(WheelRESTHandler):
         return self.redirect(self.instance.get_absolute_url() + 'list',
                              info="%d item(s) deleted" % count)
 
-    def handle_popup(self):
-        """ popup experiments - #524 """
-        return self.template("wheelcms_axle/popup.html",
-                             original="/data/powerful-editing")
-
     @applyrequest
     def handle_panel_selection_details(self, path, type, klass="", title="",
                                        target="", download=False,
@@ -829,6 +826,7 @@ class MainHandler(WheelRESTHandler):
             mode can be either "link" (any content) or "image" (only image
             based content)
         """
+        language = self.active_language()
         if not self.hasaccess():
             return self.forbidden()
 
@@ -854,7 +852,7 @@ class MainHandler(WheelRESTHandler):
         path = strip_action(path)
         original = strip_action(original)
 
-        node = start = Node.get(path)
+        node = start = Node.get(path)# , language=language)
         panels = []
 
         ## first panel: bookmarks/shortcuts
